@@ -40,16 +40,18 @@
 G_BEGIN_DECLS
 
 /* Do nothing if URI does not exist */
-void		 gedit_commands_load_uri		(GeditWindow         *window,
-							 const gchar         *uri,
+void		 gedit_commands_load_location		(GeditWindow         *window,
+							 GFile               *location,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos);
 
 /* Ignore non-existing URIs */
-gint		 gedit_commands_load_uris		(GeditWindow         *window,
-							 const GSList        *uris,
+GSList		*gedit_commands_load_locations		(GeditWindow         *window,
+							 const GSList        *locations,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos) G_GNUC_WARN_UNUSED_RESULT;
 
 void		 gedit_commands_save_document		(GeditWindow         *window,
                                                          GeditDocument       *document);
@@ -61,10 +63,11 @@ void		 gedit_commands_save_all_documents 	(GeditWindow         *window);
  */
 
 /* Create titled documens for non-existing URIs */
-gint		_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
+GSList	        *_gedit_cmd_load_files_from_prompt	(GeditWindow         *window,
 							 GSList              *files,
 							 const GeditEncoding *encoding,
-							 gint                 line_pos);
+							 gint                 line_pos,
+							 gint                 column_pos) G_GNUC_WARN_UNUSED_RESULT;
 
 void		_gedit_cmd_file_new			(GtkAction   *action,
 							 GeditWindow *window);
@@ -142,6 +145,12 @@ void		_gedit_cmd_documents_next_document	(GtkAction   *action,
 							 GeditWindow *window);
 void		_gedit_cmd_documents_move_to_new_window	(GtkAction   *action,
 							 GeditWindow *window);
+void		_gedit_cmd_documents_new_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_previous_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
+void		_gedit_cmd_documents_next_tab_group	(GtkAction   *action,
+							 GeditWindow *window);
 
 void		_gedit_cmd_help_contents		(GtkAction   *action,
 							 GeditWindow *window);
@@ -164,3 +173,4 @@ void		_gedit_cmd_file_page_setup		(GtkAction   *action,
 G_END_DECLS
 
 #endif /* __GEDIT_COMMANDS_H__ */ 
+/* ex:ts=8:noet: */
