@@ -35,6 +35,7 @@
 #include "gedit-documents-panel.h"
 #include "gedit-utils.h"
 #include "gedit-notebook.h"
+#include "gseal-gtk-compat.h"
 
 #include <glib/gi18n.h>
 
@@ -123,7 +124,9 @@ tab_get_name (GeditTab *tab)
 }
 
 static void
-get_iter_from_tab (GeditDocumentsPanel *panel, GeditTab *tab, GtkTreeIter *iter)
+get_iter_from_tab (GeditDocumentsPanel *panel,
+		   GeditTab            *tab,
+		   GtkTreeIter         *iter)
 {
 	gint num;
 	GtkWidget *nb;
@@ -518,6 +521,7 @@ menu_position (GtkMenu             *menu,
 	gint wx, wy;
 	GtkRequisition requisition;
 	GtkWidget *w;
+	GtkAllocation allocation;
 
 	w = panel->priv->treeview;
 
@@ -531,21 +535,23 @@ menu_position (GtkMenu             *menu,
 	wx = rect.x;
 	wy = rect.y;
 
-	gdk_window_get_origin (w->window, x, y);
+	gdk_window_get_origin (gtk_widget_get_window (w), x, y);
 	
 	gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
 
+	gtk_widget_get_allocation (w, &allocation);
+
 	if (gtk_widget_get_direction (w) == GTK_TEXT_DIR_RTL)
 	{
-		*x += w->allocation.x + w->allocation.width - requisition.width - 10;
+		*x += allocation.x + allocation.width - requisition.width - 10;
 	}
 	else
 	{
-		*x += w->allocation.x + 10;
+		*x += allocation.x + 10;
 	}
 
 	wy = MAX (*y + 5, *y + wy + 5);
-	wy = MIN (wy, *y + w->allocation.height - requisition.height - 5);
+	wy = MIN (wy, *y + allocation.height - requisition.height - 5);
 	
 	*y = wy;
 
@@ -772,6 +778,14 @@ gedit_documents_panel_init (GeditDocumentsPanel *panel)
 	gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (panel->priv->treeview), FALSE);
 	gtk_tree_view_set_reorderable (GTK_TREE_VIEW (panel->priv->treeview), TRUE);
 
+	/* Disable search because each time the selection is changed, the
+	   active tab is changed which focusses the view, and thus would remove
+	   the search entry, rendering it useless */
+	gtk_tree_view_set_enable_search (GTK_TREE_VIEW (panel->priv->treeview), FALSE);
+
+	/* Disable focus so it doesn't steel focus each time from the view */
+	gtk_widget_set_can_focus (panel->priv->treeview, FALSE);
+
 	g_object_set (panel->priv->treeview, "has-tooltip", TRUE, NULL);
 
 	gtk_widget_show (panel->priv->treeview);
@@ -826,3 +840,5 @@ gedit_documents_panel_new (GeditWindow *window)
 					 "window", window,
 					 NULL));
 }
+
+/* ex:ts=8:noet: */
