@@ -43,9 +43,9 @@
 #include "gedit-file-chooser-dialog.h"
 #include "gedit-encodings-combo-box.h"
 #include "gedit-language-manager.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-debug.h"
 #include "gedit-enum-types.h"
+#include "gedit-settings.h"
 
 #define GEDIT_FILE_CHOOSER_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), GEDIT_TYPE_FILE_CHOOSER_DIALOG, GeditFileChooserDialogPrivate))
 
@@ -54,6 +54,8 @@
 
 struct _GeditFileChooserDialogPrivate
 {
+	GSettings *filter_settings;
+
 	GtkWidget *option_menu;
 	GtkWidget *extra_widget;
 
@@ -64,12 +66,28 @@ struct _GeditFileChooserDialogPrivate
 
 G_DEFINE_TYPE(GeditFileChooserDialog, gedit_file_chooser_dialog, GTK_TYPE_FILE_CHOOSER_DIALOG)
 
+static void
+gedit_file_chooser_dialog_dispose (GObject *object)
+{
+	GeditFileChooserDialog *dialog = GEDIT_FILE_CHOOSER_DIALOG (object);
+
+	if (dialog->priv->filter_settings != NULL)
+	{
+		g_object_unref (dialog->priv->filter_settings);
+		dialog->priv->filter_settings = NULL;
+	}
+
+	G_OBJECT_CLASS (gedit_file_chooser_dialog_parent_class)->dispose (object);
+}
+
 static void
 gedit_file_chooser_dialog_class_init (GeditFileChooserDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	g_type_class_add_private (object_class, sizeof(GeditFileChooserDialogPrivate));
+	object_class->dispose = gedit_file_chooser_dialog_dispose;
+
+	g_type_class_add_private (object_class, sizeof (GeditFileChooserDialogPrivate));
 }
 
 static void
@@ -107,16 +125,10 @@ create_option_menu (GeditFileChooserDialog *dialog)
 static void
 update_newline_visibility (GeditFileChooserDialog *dialog)
 {
-	if (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE)
-	{
-		gtk_widget_show (dialog->priv->newline_label);
-		gtk_widget_show (dialog->priv->newline_combo);
-	}
-	else
-	{
-		gtk_widget_hide (dialog->priv->newline_label);
-		gtk_widget_hide (dialog->priv->newline_combo);
-	}
+	gboolean visible = gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE;
+
+	gtk_widget_set_visible (dialog->priv->newline_label, visible);
+	gtk_widget_set_visible (dialog->priv->newline_combo, visible);
 }
 
 static void
@@ -250,9 +262,6 @@ filter_changed (GeditFileChooserDialog *dialog,
 {
 	GtkFileFilter *filter;
 
-	if (!gedit_prefs_manager_active_file_filter_can_set ())
-		return;
-
 	filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
 	if (filter != NULL)
 	{
@@ -267,7 +276,8 @@ filter_changed (GeditFileChooserDialog *dialog,
 
 		gedit_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
 
-		gedit_prefs_manager_set_active_file_filter (id);
+		g_settings_set_int (dialog->priv->filter_settings,
+				    GEDIT_SETTINGS_ACTIVE_FILE_FILTER, id);
 	}
 }
 
@@ -353,6 +363,8 @@ static void
 gedit_file_chooser_dialog_init (GeditFileChooserDialog *dialog)
 {
 	dialog->priv = GEDIT_FILE_CHOOSER_DIALOG_GET_PRIVATE (dialog);
+	
+	dialog->priv->filter_settings = g_settings_new ("org.gnome.gedit.state.file-filter");
 }
 
 static GtkWidget *
@@ -387,11 +399,14 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
 			  NULL);
 
 	if (encoding != NULL)
+	{
 		gedit_encodings_combo_box_set_selected_encoding (
 				GEDIT_ENCODINGS_COMBO_BOX (GEDIT_FILE_CHOOSER_DIALOG (result)->priv->option_menu),
 				encoding);
+	}
 
-	active_filter = gedit_prefs_manager_get_active_file_filter ();
+	active_filter = g_settings_get_int (GEDIT_FILE_CHOOSER_DIALOG (result)->priv->filter_settings,
+					    GEDIT_SETTINGS_ACTIVE_FILE_FILTER);
 	gedit_debug_message (DEBUG_COMMANDS, "Active filter: %d", active_filter);
 
 	/* Filters */
@@ -439,7 +454,9 @@ gedit_file_chooser_dialog_new_valist (const gchar          *title,
 		    (response_id == GTK_RESPONSE_ACCEPT) ||
 		    (response_id == GTK_RESPONSE_YES) ||
 		    (response_id == GTK_RESPONSE_APPLY))
+		{
 			gtk_dialog_set_default_response (GTK_DIALOG (result), response_id);
+		}
 
 		button_text = va_arg (varargs, const gchar *);
 	}
@@ -505,17 +522,14 @@ gedit_file_chooser_dialog_get_encoding (GeditFileChooserDialog *dialog)
 				GEDIT_ENCODINGS_COMBO_BOX (dialog->priv->option_menu));
 }
 
-void
-gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog  *dialog,
-					    GeditDocumentNewlineType newline_type)
+static void
+set_enum_combo (GtkComboBox *combo,
+                gint         value)
 {
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 
-	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
-	g_return_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
-
-	model = GTK_TREE_MODEL (dialog->priv->newline_store);
+	model = gtk_combo_box_get_model (combo);
 
 	if (!gtk_tree_model_get_iter_first (model, &iter))
 	{
@@ -524,19 +538,29 @@ gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog  *dialog,
 
 	do
 	{
-		GeditDocumentNewlineType nt;
+		gint nt;
 
 		gtk_tree_model_get (model, &iter, 1, &nt, -1);
 
-		if (newline_type == nt)
+		if (value == nt)
 		{
-			gtk_combo_box_set_active_iter (GTK_COMBO_BOX (dialog->priv->newline_combo),
-			                               &iter);
+			gtk_combo_box_set_active_iter (combo, &iter);
 			break;
 		}
 	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
+void
+gedit_file_chooser_dialog_set_newline_type (GeditFileChooserDialog   *dialog,
+					    GeditDocumentNewlineType  newline_type)
+{
+	g_return_if_fail (GEDIT_IS_FILE_CHOOSER_DIALOG (dialog));
+	g_return_if_fail (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (dialog)) == GTK_FILE_CHOOSER_ACTION_SAVE);
+
+	set_enum_combo (GTK_COMBO_BOX (dialog->priv->newline_combo),
+	                newline_type);
+}
+
 GeditDocumentNewlineType
 gedit_file_chooser_dialog_get_newline_type (GeditFileChooserDialog *dialog)
 {
@@ -558,4 +582,5 @@ gedit_file_chooser_dialog_get_newline_type (GeditFileChooserDialog *dialog)
 
 	return newline_type;
 }
+
 /* ex:ts=8:noet: */
