@@ -42,12 +42,14 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
+#include "gedit-settings.h"
 #include "gedit-utils.h"
 #include "gedit-document.h"
 #include "gedit-io-error-message-area.h"
-#include "gedit-prefs-manager.h"
 #include <gedit/gedit-encodings-combo-box.h>
 
+#include "gseal-gtk-compat.h"
+
 #if !GTK_CHECK_VERSION (2, 17, 1)
 #include "gedit-message-area.h"
 #endif
@@ -61,15 +63,19 @@ is_recoverable_error (const GError *error)
 
 	if (error->domain == G_IO_ERROR)
 	{
-		switch (error->code) {
-		case G_IO_ERROR_PERMISSION_DENIED:
-		case G_IO_ERROR_NOT_FOUND:
-		case G_IO_ERROR_HOST_NOT_FOUND:
-		case G_IO_ERROR_TIMED_OUT:
-		case G_IO_ERROR_NOT_MOUNTABLE_FILE:
-		case G_IO_ERROR_NOT_MOUNTED:
-		case G_IO_ERROR_BUSY:
-			is_recoverable = TRUE;
+		switch (error->code)
+		{
+			case G_IO_ERROR_PERMISSION_DENIED:
+			case G_IO_ERROR_NOT_FOUND:
+			case G_IO_ERROR_HOST_NOT_FOUND:
+			case G_IO_ERROR_TIMED_OUT:
+			case G_IO_ERROR_NOT_MOUNTABLE_FILE:
+			case G_IO_ERROR_NOT_MOUNTED:
+			case G_IO_ERROR_BUSY:
+				is_recoverable = TRUE;
+				break;
+			default:
+				break;
 		}
 	}
 
@@ -106,13 +112,11 @@ info_bar_add_stock_button_with_text (GtkInfoBar  *infobar,
 				     gint         response_id)
 {
 	GtkWidget *button;
-	
-	button = gedit_gtk_button_new_with_stock_icon (text, stock_id);
-	gtk_widget_show (button);
+	GtkWidget *image;
 
-	gtk_info_bar_add_action_widget (infobar,
-					button,
-					response_id);
+	button = gtk_info_bar_add_button (infobar, text, response_id);
+	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_BUTTON);
+	gtk_button_set_image (GTK_BUTTON (button), image);
 }
 #endif
 
@@ -146,7 +150,7 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	if (secondary_text != NULL)
@@ -156,7 +160,7 @@ set_message_area_text_and_icon (GtkWidget   *message_area,
 		secondary_label = gtk_label_new (secondary_markup);
 		g_free (secondary_markup);
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -213,123 +217,135 @@ static gboolean
 parse_gio_error (gint          code,
 	         gchar       **error_message, 
 	         gchar       **message_details, 
-	         const gchar  *uri, 
+	         GFile        *location,
 	         const gchar  *uri_for_display)
 {
 	gboolean ret = TRUE;
 
 	switch (code)
 	{
-	case G_IO_ERROR_NOT_FOUND:
-	case G_IO_ERROR_NOT_DIRECTORY:
-		*error_message = g_strdup_printf (_("Could not find the file %s."),
-						  uri_for_display);
-		*message_details = g_strdup (_("Please check that you typed the "
-				      	       "location correctly and try again."));
-		break;
-	case G_IO_ERROR_NOT_SUPPORTED:
-		{
-			gchar *scheme_string;
-			gchar *scheme_markup;
-			
-			scheme_string = g_uri_parse_scheme (uri);
+		case G_IO_ERROR_NOT_FOUND:
+		case G_IO_ERROR_NOT_DIRECTORY:
+			*error_message = g_strdup_printf (_("Could not find the file %s."),
+							  uri_for_display);
+			*message_details = g_strdup (_("Please check that you typed the "
+					      	       "location correctly and try again."));
+			break;
 
-			if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
+		case G_IO_ERROR_NOT_SUPPORTED:
 			{
-				scheme_markup = g_markup_printf_escaped ("<i>%s:</i>", scheme_string);
+				gchar *scheme_string = NULL;
+				gchar *scheme_markup;
 
-				/* Translators: %s is a URI scheme (like for example http:, ftp:, etc.) */
-				*message_details = g_strdup_printf (_("gedit cannot handle %s locations."),
-								   scheme_markup);
-				g_free (scheme_markup);
-			}
-			else
-			{
-				*message_details = g_strdup (_("gedit cannot handle this location."));
-			}	
-
-			g_free (scheme_string);
-		}
-		break;
-
-	case G_IO_ERROR_NOT_MOUNTABLE_FILE:
-		*message_details = g_strdup (_("The location of the file cannot be mounted."));
-		break;
-	
-	case G_IO_ERROR_NOT_MOUNTED:
-		*message_details = g_strdup( _("The location of the file cannot be accessed because it is not mounted."));
-
-		break;	
-	case G_IO_ERROR_IS_DIRECTORY:
-		*error_message = g_strdup_printf (_("%s is a directory."),
-						 uri_for_display);
-		*message_details = g_strdup (_("Please check that you typed the "
-					      "location correctly and try again."));
-		break;
-		
-	case G_IO_ERROR_INVALID_FILENAME:
-		*error_message = g_strdup_printf (_("%s is not a valid location."),
-						 uri_for_display);
-		*message_details = g_strdup (_("Please check that you typed the "
-					      "location correctly and try again."));
-		break;
-		
-	case G_IO_ERROR_HOST_NOT_FOUND:
-		/* This case can be hit for user-typed strings like "foo" due to
-		 * the code that guesses web addresses when there's no initial "/".
-		 * But this case is also hit for legitimate web addresses when
-		 * the proxy is set up wrong.
-		 */
-		{
-			gchar *hn = NULL;
-
-			if (gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
-			{
-				if (hn != NULL)
+				if (location)
 				{
-					gchar *host_markup;
-					gchar *host_name;
+					scheme_string = g_file_get_uri_scheme (location);
+				}
 
-					host_name = gedit_utils_make_valid_utf8 (hn);
-					g_free (hn);
+				if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
+				{
+					scheme_markup = g_markup_printf_escaped ("<i>%s:</i>", scheme_string);
 
-					host_markup = g_markup_printf_escaped ("<i>%s</i>", host_name);
-					g_free (host_name);
+					/* Translators: %s is a URI scheme (like for example http:, ftp:, etc.) */
+					*message_details = g_strdup_printf (_("gedit cannot handle %s locations."),
+									   scheme_markup);
+					g_free (scheme_markup);
+				}
+				else
+				{
+					*message_details = g_strdup (_("gedit cannot handle this location."));
+				}	
 
-					/* Translators: %s is a host name */
+				g_free (scheme_string);
+			}
+			break;
+
+		case G_IO_ERROR_NOT_MOUNTABLE_FILE:
+			*message_details = g_strdup (_("The location of the file cannot be mounted."));
+			break;
+	
+		case G_IO_ERROR_NOT_MOUNTED:
+			*message_details = g_strdup( _("The location of the file cannot be accessed because it is not mounted."));
+
+			break;	
+		case G_IO_ERROR_IS_DIRECTORY:
+			*error_message = g_strdup_printf (_("%s is a directory."),
+							 uri_for_display);
+			*message_details = g_strdup (_("Please check that you typed the "
+						      "location correctly and try again."));
+			break;
+		
+		case G_IO_ERROR_INVALID_FILENAME:
+			*error_message = g_strdup_printf (_("%s is not a valid location."),
+							 uri_for_display);
+			*message_details = g_strdup (_("Please check that you typed the "
+						      "location correctly and try again."));
+			break;
+		
+		case G_IO_ERROR_HOST_NOT_FOUND:
+			/* This case can be hit for user-typed strings like "foo" due to
+			 * the code that guesses web addresses when there's no initial "/".
+			 * But this case is also hit for legitimate web addresses when
+			 * the proxy is set up wrong.
+			 */
+			{
+				gchar *hn = NULL;
+				gchar *uri = NULL;
+
+				if (location)
+				{
+					uri = g_file_get_uri (location);
+				}
+
+				if (uri && gedit_utils_decode_uri (uri, NULL, NULL, &hn, NULL, NULL))
+				{
+					if (hn != NULL)
+					{
+						gchar *host_markup;
+						gchar *host_name;
+
+						host_name = gedit_utils_make_valid_utf8 (hn);
+						g_free (hn);
+
+						host_markup = g_markup_printf_escaped ("<i>%s</i>", host_name);
+						g_free (host_name);
+
+						/* Translators: %s is a host name */
+						*message_details = g_strdup_printf (
+							_("Host %s could not be found. "
+							"Please check that your proxy settings "
+							"are correct and try again."),
+							host_markup);
+
+						g_free (host_markup);
+					}
+				}
+
+				g_free (uri);
+			
+				if (!*message_details)
+				{
+					/* use the same string as INVALID_HOST */
 					*message_details = g_strdup_printf (
-						_("Host %s could not be found. "
-						"Please check that your proxy settings "
-						"are correct and try again."),
-						host_markup);
-
-					g_free (host_markup);
+						_("Hostname was invalid. "
+						  "Please check that you typed the location "
+						  "correctly and try again."));
 				}
 			}
-			
-			if (!*message_details)
-			{
-				/* use the same string as INVALID_HOST */
-				*message_details = g_strdup_printf (
-					_("Hostname was invalid. "
-					  "Please check that you typed the location "
-					  "correctly and try again."));
-			}
-		}
-		break;
+			break;
 
-	case G_IO_ERROR_NOT_REGULAR_FILE:
-		*message_details = g_strdup_printf (_("%s is not a regular file."),
-						   uri_for_display);
-		break;
+		case G_IO_ERROR_NOT_REGULAR_FILE:
+			*message_details = g_strdup_printf (_("%s is not a regular file."),
+							   uri_for_display);
+			break;
 
-	case G_IO_ERROR_TIMED_OUT:
-		*message_details = g_strdup (_("Connection timed out. Please try again."));
-		break;
+		case G_IO_ERROR_TIMED_OUT:
+			*message_details = g_strdup (_("Connection timed out. Please try again."));
+			break;
 
-	default:
-		ret = FALSE;
-		break;
+		default:
+			ret = FALSE;
+			break;
 	}
 
 	return ret;
@@ -339,20 +355,20 @@ static gboolean
 parse_gedit_error (gint          code,
 	           gchar       **error_message, 
 	           gchar       **message_details, 
-	           const gchar  *uri, 
+	           GFile        *location,
 	           const gchar  *uri_for_display)
 {
 	gboolean ret = TRUE;
 
 	switch (code)
 	{
-	case GEDIT_DOCUMENT_ERROR_TOO_BIG:
-		*message_details = g_strdup (_("The file is too big."));
-		break;
+		case GEDIT_DOCUMENT_ERROR_TOO_BIG:
+			*message_details = g_strdup (_("The file is too big."));
+			break;
 
-	default:
-		ret = FALSE;
-		break;
+		default:
+			ret = FALSE;
+			break;
 	}
 
 	return ret;
@@ -362,7 +378,7 @@ static void
 parse_error (const GError *error, 
 	     gchar       **error_message, 
 	     gchar       **message_details, 
-	     const gchar  *uri, 
+	     GFile        *location,
 	     const gchar  *uri_for_display)
 {
 	gboolean ret = FALSE;
@@ -372,7 +388,7 @@ parse_error (const GError *error,
 		ret = parse_gio_error (error->code,
 				       error_message,
 				       message_details,
-				       uri,
+				       location,
 				       uri_for_display);
 	}
 	else if (error->domain == GEDIT_DOCUMENT_ERROR)
@@ -380,21 +396,21 @@ parse_error (const GError *error,
 		ret = parse_gedit_error (error->code,
 					 error_message,
 					 message_details,
-					 uri,
+					 location,
 					 uri_for_display);
 	}
 	
 	if (!ret)
 	{
 		g_warning ("Hit unhandled case %d (%s) in %s.", 
-			   error->code, error->message, G_STRFUNC);	
+			   error->code, error->message, G_STRFUNC);
 		*message_details = g_strdup_printf (_("Unexpected error: %s"), 
-						   error->message);
+						    error->message);
 	}
 }
 
 GtkWidget *
-gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
+gedit_unrecoverable_reverting_error_message_area_new (GFile        *location,
 						      const GError *error)
 {
 	gchar *error_message = NULL;
@@ -404,19 +420,19 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
 			      (error->domain == G_IO_ERROR), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
-	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri,
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -429,12 +445,14 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 	}
 	else
 	{
-		parse_error (error, &error_message, &message_details, uri, uri_for_display);
+		parse_error (error, &error_message, &message_details, location, uri_for_display);
 	}
 
 	if (error_message == NULL)
+	{
 		error_message = g_strdup_printf (_("Could not revert the file %s."),
 						 uri_for_display);
+	}
 
 	message_area = create_io_loading_error_message_area (error_message,
 							     message_details,
@@ -448,7 +466,8 @@ gedit_unrecoverable_reverting_error_message_area_new (const gchar  *uri,
 }
 
 static void
-create_combo_box (GtkWidget *message_area, GtkWidget *vbox)
+create_combo_box (GtkWidget *message_area,
+		  GtkWidget *vbox)
 {
 	GtkWidget *hbox;
 	GtkWidget *label;
@@ -570,7 +589,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	if (secondary_text != NULL)
@@ -580,7 +599,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 		secondary_label = gtk_label_new (secondary_markup);
 		g_free (secondary_markup);
 		gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-		GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+		gtk_widget_set_can_focus (secondary_label, TRUE);
 		gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 		gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -595,7 +614,7 @@ create_conversion_error_message_area (const gchar *primary_text,
 }
 
 GtkWidget *
-gedit_io_loading_error_message_area_new (const gchar         *uri,
+gedit_io_loading_error_message_area_new (GFile               *location,
 					 const GeditEncoding *encoding,
 					 const GError        *error)
 {
@@ -609,13 +628,19 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 	gboolean edit_anyway = FALSE;
 	gboolean convert_error = FALSE;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == G_CONVERT_ERROR) ||
 			      (error->domain == GEDIT_DOCUMENT_ERROR) ||
 			      (error->domain == G_IO_ERROR), NULL);
-	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+
+	if (location)
+	{
+		full_formatted_uri = gedit_utils_uri_for_display (location);
+	}
+	else
+	{
+		full_formatted_uri = g_strdup ("stdin");
+	}
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -645,11 +670,9 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 	         (error->domain == GEDIT_DOCUMENT_ERROR &&
 	         error->code == GEDIT_DOCUMENT_ERROR_ENCODING_AUTO_DETECTION_FAILED))
 	{
-		error_message = g_strdup_printf (_("Could not open the file %s."),
-						 uri_for_display);
 		message_details = g_strconcat (_("gedit has not been able to detect "
-				               "the character encoding."), "\n", 
-				               _("Please check that you are not trying to open a binary file."), "\n",
+					         "the character encoding."), "\n",
+					       _("Please check that you are not trying to open a binary file."), "\n",
 					       _("Select a character encoding from the menu and try again."), NULL);
 		convert_error = TRUE;
 	}
@@ -677,7 +700,13 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 	}
 	else
 	{
-		parse_error (error, &error_message, &message_details, uri, uri_for_display);
+		parse_error (error, &error_message, &message_details, location, uri_for_display);
+	}
+
+	if (error_message == NULL)
+	{
+		error_message = g_strdup_printf (_("Could not open the file %s."),
+						 uri_for_display);
 	}
 
 	if (convert_error)
@@ -702,10 +731,9 @@ gedit_io_loading_error_message_area_new (const gchar         *uri,
 }
 
 GtkWidget *
-gedit_conversion_error_while_saving_message_area_new (
-						const gchar         *uri,
-						const GeditEncoding *encoding,
-				    		const GError        *error)
+gedit_conversion_error_while_saving_message_area_new (GFile               *location,
+						      const GeditEncoding *encoding,
+						      const GError        *error)
 {
 	gchar *error_message = NULL;
 	gchar *message_details = NULL;
@@ -715,19 +743,20 @@ gedit_conversion_error_while_saving_message_area_new (
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 	
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
-	g_return_val_if_fail (error->domain == G_CONVERT_ERROR, NULL);
+	g_return_val_if_fail (error->domain == G_CONVERT_ERROR ||
+	                      error->domain == G_IO_ERROR, NULL);
 	g_return_val_if_fail (encoding != NULL, NULL);
 	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 	
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -775,7 +804,7 @@ gedit_conversion_error_message_area_get_encoding (GtkWidget *message_area)
 }
 
 GtkWidget *
-gedit_file_already_open_warning_message_area_new (const gchar *uri)
+gedit_file_already_open_warning_message_area_new (GFile *location)
 {
 	GtkWidget *message_area;
 	GtkWidget *hbox_content;
@@ -790,15 +819,17 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	gchar *full_formatted_uri;
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
-	
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
+
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 	
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -848,7 +879,7 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("gedit opened this instance of the file in a non-editable way. "
@@ -858,7 +889,7 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -871,9 +902,8 @@ gedit_file_already_open_warning_message_area_new (const gchar *uri)
 }
 
 GtkWidget *
-gedit_externally_modified_saving_error_message_area_new (
-						const gchar  *uri,
-						const GError *error)
+gedit_externally_modified_saving_error_message_area_new (GFile        *location,
+							 const GError *error)
 {
 	GtkWidget *message_area;
 	GtkWidget *hbox_content;
@@ -889,19 +919,19 @@ gedit_externally_modified_saving_error_message_area_new (
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail (error->domain == GEDIT_DOCUMENT_ERROR, NULL);
 	g_return_val_if_fail (error->code == GEDIT_DOCUMENT_ERROR_EXTERNALLY_MODIFIED, NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -954,7 +984,7 @@ gedit_externally_modified_saving_error_message_area_new (
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("If you save it, all the external changes could be lost. Save it anyway?");
@@ -963,7 +993,7 @@ gedit_externally_modified_saving_error_message_area_new (
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -976,7 +1006,7 @@ gedit_externally_modified_saving_error_message_area_new (
 }
 
 GtkWidget *
-gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
+gedit_no_backup_saving_error_message_area_new (GFile        *location,
 					       const GError *error)
 {
 	GtkWidget *message_area;
@@ -992,22 +1022,24 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gchar *full_formatted_uri;
 	gchar *uri_for_display;
 	gchar *temp_uri_for_display;
+	gboolean create_backup_copy;
+	GSettings *editor_settings;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail (((error->domain == GEDIT_DOCUMENT_ERROR &&
 			        error->code == GEDIT_DOCUMENT_ERROR_CANT_CREATE_BACKUP) ||
 			       (error->domain == G_IO_ERROR &&
 			        error->code == G_IO_ERROR_CANT_CREATE_BACKUP)), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
 	 */
 	temp_uri_for_display = gedit_utils_str_middle_truncate (full_formatted_uri, 
-								MAX_URI_IN_DIALOG_LENGTH);								
+								MAX_URI_IN_DIALOG_LENGTH);
 	g_free (full_formatted_uri);
 
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
@@ -1045,14 +1077,23 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_box_pack_start (GTK_BOX (hbox_content), vbox, TRUE, TRUE, 0);
 
-	// FIXME: review this messages
+	editor_settings = g_settings_new ("org.gnome.gedit.preferences.editor");
 
-	if (gedit_prefs_manager_get_create_backup_copy ())
+	create_backup_copy = g_settings_get_boolean (editor_settings,
+						     GEDIT_SETTINGS_CREATE_BACKUP_COPY);
+	g_object_unref (editor_settings);
+
+	/* FIXME: review this messages */
+	if (create_backup_copy)
+	{
 		primary_text = g_strdup_printf (_("Could not create a backup file while saving %s"),
 						uri_for_display);
+	}
 	else
+	{
 		primary_text = g_strdup_printf (_("Could not create a temporary backup file while saving %s"),
 						uri_for_display);
+	}
 
 	g_free (uri_for_display);
 
@@ -1064,7 +1105,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	gtk_label_set_use_markup (GTK_LABEL (primary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (primary_label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (primary_label), 0, 0.5);
-	GTK_WIDGET_SET_FLAGS (primary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (primary_label, TRUE);
 	gtk_label_set_selectable (GTK_LABEL (primary_label), TRUE);
 
 	secondary_text = _("gedit could not back up the old copy of the file before saving the new one. "
@@ -1075,7 +1116,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 	secondary_label = gtk_label_new (secondary_markup);
 	g_free (secondary_markup);
 	gtk_box_pack_start (GTK_BOX (vbox), secondary_label, TRUE, TRUE, 0);
-	GTK_WIDGET_SET_FLAGS (secondary_label, GTK_CAN_FOCUS);
+	gtk_widget_set_can_focus (secondary_label, TRUE);
 	gtk_label_set_use_markup (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_line_wrap (GTK_LABEL (secondary_label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (secondary_label), TRUE);
@@ -1088,7 +1129,7 @@ gedit_no_backup_saving_error_message_area_new (const gchar  *uri,
 }
 
 GtkWidget *
-gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
+gedit_unrecoverable_saving_error_message_area_new (GFile        *location,
 						   const GError *error)
 {
 	gchar *error_message = NULL;
@@ -1100,12 +1141,12 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 	gchar *temp_uri_for_display;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 	g_return_val_if_fail (error != NULL, NULL);
 	g_return_val_if_fail ((error->domain == GEDIT_DOCUMENT_ERROR) || 
 			      (error->domain == G_IO_ERROR), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -1120,7 +1161,7 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 
 	if (is_gio_error (error, G_IO_ERROR_NOT_SUPPORTED))
 	{
-		scheme_string = g_uri_parse_scheme (uri);
+		scheme_string = g_file_get_uri_scheme (location);
 
 		if ((scheme_string != NULL) && g_utf8_validate (scheme_string, -1, NULL))
 		{
@@ -1189,13 +1230,15 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 		parse_error (error, 
 			     &error_message, 
 			     &message_details, 
-			     uri, 
+			     location,
 			     uri_for_display);
 	}
 
 	if (error_message == NULL)
+	{
 		error_message = g_strdup_printf (_("Could not save the file %s."),
 						 uri_for_display);
+	}
 
 	message_area = create_io_loading_error_message_area (error_message,
 							     message_details,
@@ -1209,8 +1252,8 @@ gedit_unrecoverable_saving_error_message_area_new (const gchar  *uri,
 }
 
 GtkWidget *
-gedit_externally_modified_message_area_new (const gchar *uri,
-					    gboolean     document_modified)
+gedit_externally_modified_message_area_new (GFile    *location,
+					    gboolean  document_modified)
 {
 	gchar *full_formatted_uri;
 	gchar *uri_for_display;
@@ -1219,9 +1262,9 @@ gedit_externally_modified_message_area_new (const gchar *uri,
 	const gchar *secondary_text;
 	GtkWidget *message_area;
 
-	g_return_val_if_fail (uri != NULL, NULL);
+	g_return_val_if_fail (G_IS_FILE (location), NULL);
 
-	full_formatted_uri = gedit_utils_uri_for_display (uri);
+	full_formatted_uri = gedit_utils_uri_for_display (location);
 
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
@@ -1234,9 +1277,10 @@ gedit_externally_modified_message_area_new (const gchar *uri,
 	uri_for_display = g_markup_printf_escaped ("<i>%s</i>", temp_uri_for_display);
 	g_free (temp_uri_for_display);
 
-	// FIXME: review this message, it's not clear since for the user the "modification"
-	// could be interpreted as the changes he made in the document. beside "reading" is
-	// not accurate (since last load/save)
+	/* FIXME: review this message, it's not clear since for the user the "modification"
+	 * could be interpreted as the changes he made in the document. beside "reading" is
+	 * not accurate (since last load/save)
+	 */
 	primary_text = g_strdup_printf (_("The file %s changed on disk."),
 					uri_for_display);
 	g_free (uri_for_display);
@@ -1279,3 +1323,4 @@ gedit_externally_modified_message_area_new (const gchar *uri,
 	return message_area;
 }
 
+/* ex:ts=8:noet: */
