@@ -58,23 +58,25 @@ enum
 
 struct _GeditPluginManagerPrivate
 {
-	GtkWidget	*tree;
-
-	GtkWidget	*about_button;
-	GtkWidget	*configure_button;
-
 	GeditPluginsEngine *engine;
 
-	GtkWidget 	*about;
+	GtkWidget          *tree;
+
+	GtkWidget          *about_button;
+	GtkWidget          *configure_button;
+
+	GtkWidget          *about;
 	
-	GtkWidget	*popup_menu;
+	GtkWidget          *popup_menu;
 };
 
 G_DEFINE_TYPE(GeditPluginManager, gedit_plugin_manager, GTK_TYPE_VBOX)
 
-static GeditPluginInfo *plugin_manager_get_selected_plugin (GeditPluginManager *pm); 
-static void plugin_manager_toggle_active (GeditPluginManager *pm, GtkTreeIter *iter, GtkTreeModel *model);
-static void gedit_plugin_manager_finalize (GObject *object);
+static GeditPluginInfo	*plugin_manager_get_selected_plugin	(GeditPluginManager *pm); 
+static void		 plugin_manager_toggle_active		(GeditPluginManager *pm,
+								 GtkTreeIter        *iter,
+								 GtkTreeModel       *model);
+static void		 gedit_plugin_manager_finalize		(GObject            *object);
 
 static void 
 gedit_plugin_manager_class_init (GeditPluginManagerClass *klass)
@@ -125,7 +127,7 @@ about_button_cb (GtkWidget          *button,
 			  &pm->priv->about);
 
 	gtk_window_set_transient_for (GTK_WINDOW (pm->priv->about),
-				      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET(pm))));
+				      GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (pm))));
 	gtk_widget_show (pm->priv->about);
 }
 
@@ -231,10 +233,9 @@ active_toggled_cb (GtkCellRendererToggle *cell,
 }
 
 static void
-cursor_changed_cb (GtkTreeView *view,
-		   gpointer     data)
+cursor_changed_cb (GtkTreeView        *view,
+		   GeditPluginManager *pm)
 {
-	GeditPluginManager *pm = data;
 	GeditPluginInfo *info;
 
 	gedit_debug (DEBUG_PLUGINS);
@@ -249,12 +250,11 @@ cursor_changed_cb (GtkTreeView *view,
 }
 
 static void
-row_activated_cb (GtkTreeView       *tree_view,
-		  GtkTreePath       *path,
-		  GtkTreeViewColumn *column,
-		  gpointer           data)
+row_activated_cb (GtkTreeView        *tree_view,
+		  GtkTreePath        *path,
+		  GtkTreeViewColumn  *column,
+		  GeditPluginManager *pm)
 {
-	GeditPluginManager *pm = data;
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 
@@ -335,7 +335,8 @@ plugin_manager_set_active (GeditPluginManager *pm,
 	if (active)
 	{
 		/* activate the plugin */
-		if (!gedit_plugins_engine_activate_plugin (pm->priv->engine, info)) {
+		if (!gedit_plugins_engine_activate_plugin (pm->priv->engine, info))
+		{
 			gedit_debug_message (DEBUG_PLUGINS, "Could not activate %s.\n", 
 					     gedit_plugin_info_get_name (info));
 
@@ -345,7 +346,8 @@ plugin_manager_set_active (GeditPluginManager *pm,
 	else
 	{
 		/* deactivate the plugin */
-		if (!gedit_plugins_engine_deactivate_plugin (pm->priv->engine, info)) {
+		if (!gedit_plugins_engine_deactivate_plugin (pm->priv->engine, info))
+		{
 			gedit_debug_message (DEBUG_PLUGINS, "Could not deactivate %s.\n", 
 					     gedit_plugin_info_get_name (info));
 
@@ -353,6 +355,9 @@ plugin_manager_set_active (GeditPluginManager *pm,
 		}
 	}
 
+	/* cause the configure button sensitivity to be updated */
+	cursor_changed_cb (GTK_TREE_VIEW (pm->priv->tree), pm);
+
 	return res;
 }
 
@@ -411,10 +416,10 @@ plugin_manager_set_active_all (GeditPluginManager *pm,
 
 	gtk_tree_model_get_iter_first (model, &iter);
 
-	do {
+	do
+	{
 		plugin_manager_set_active (pm, &iter, model, active);
-	}
-	while (gtk_tree_model_iter_next (model, &iter));
+	} while (gtk_tree_model_iter_next (model, &iter));
 }
 
 /* Callback used as the interactive search comparison function */
@@ -717,11 +722,11 @@ plugin_manager_construct_tree (GeditPluginManager *pm)
 					     NULL);
 
 	g_signal_connect (pm->priv->tree,
-			  "cursor_changed",
+			  "cursor-changed",
 			  G_CALLBACK (cursor_changed_cb),
 			  pm);
 	g_signal_connect (pm->priv->tree,
-			  "row_activated",
+			  "row-activated",
 			  G_CALLBACK (row_activated_cb),
 			  pm);
 
@@ -765,8 +770,7 @@ plugin_toggled_cb (GeditPluginsEngine *engine,
 			GeditPluginInfo *tinfo;
 			gtk_tree_model_get (model, &iter, INFO_COLUMN, &tinfo, -1);
 			info_found = info == tinfo;
-		}
-		while (!info_found && gtk_tree_model_iter_next (model, &iter));
+		} while (!info_found && gtk_tree_model_iter_next (model, &iter));
 	}
 
 	if (!info_found)
@@ -776,10 +780,12 @@ plugin_toggled_cb (GeditPluginsEngine *engine,
 		return;
 	}
 
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter, ACTIVE_COLUMN, gedit_plugin_info_is_active (info), -1);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			    ACTIVE_COLUMN, gedit_plugin_info_is_active (info),
+			    -1);
 }
 
-static void 
+static void
 gedit_plugin_manager_init (GeditPluginManager *pm)
 {
 	GtkWidget *label;
@@ -790,9 +796,7 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 
 	pm->priv = GEDIT_PLUGIN_MANAGER_GET_PRIVATE (pm);
 
-	/*
-	 * Always we create the manager, firstly we rescan the plugins directory
-	 */
+	/* Before we create the manager, we rescan the plugins directory */
 	gedit_plugins_engine_rescan_plugins (gedit_plugins_engine_get_default ());
 
 	gtk_box_set_spacing (GTK_BOX (pm), 6);
@@ -830,7 +834,7 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 									   GTK_STOCK_PREFERENCES);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox), pm->priv->configure_button);
 
-	/* setup a window of a sane size. */
+	/* Set a sane size for the window */
 	gtk_widget_set_size_request (GTK_WIDGET (viewport), 270, 100);
 
 	g_signal_connect (pm->priv->about_button,
@@ -887,4 +891,5 @@ GtkWidget *gedit_plugin_manager_new (void)
 {
 	return g_object_new (GEDIT_TYPE_PLUGIN_MANAGER,0);
 }
+
 /* ex:ts=8:noet: */
