@@ -46,7 +46,6 @@
 
 #include "gedit-debug.h"
 #include "gedit-plugins-engine.h"
-#include "gedit-prefs-manager-app.h"
 #include "gedit-metadata-manager.h"
 #include "gedit-window.h"
 #include "gedit-app.h"
@@ -268,8 +267,10 @@ close_confirmation_dialog_response_handler (GeditCloseConfirmationDialog *dlg,
 		default:
 			/* disconnect window_state_changed where needed */
 			for (l = window_dirty_list; l != NULL; l = l->next)
+			{
 				g_signal_handlers_disconnect_by_func (window,
 						window_state_change, NULL);
+			}
 			g_slist_free (window_dirty_list);
 			window_dirty_list = NULL;
 
@@ -343,7 +344,8 @@ ask_next_confirmation (void)
 
 /* quit_requested handler for the master client */
 static void
-client_quit_requested_cb (EggSMClient *client, gpointer data)
+client_quit_requested_cb (EggSMClient *client,
+			  gpointer     data)
 {
 	GeditApp *app;
 	const GList *l;
@@ -381,31 +383,9 @@ client_quit_requested_cb (EggSMClient *client, gpointer data)
 
 /* quit handler for the master client */
 static void
-client_quit_cb (EggSMClient *client, gpointer data)
+client_quit_cb (EggSMClient *client,
+		gpointer     data)
 {
-#if 0
-	gedit_debug (DEBUG_SESSION);
-
-	if (!client->save_yourself_emitted)
-		gedit_file_close_all ();
-
-	gedit_debug_message (DEBUG_FILE, "All files closed.");
-	
-	bonobo_mdi_destroy (BONOBO_MDI (gedit_mdi));
-	
-	gedit_debug_message (DEBUG_FILE, "Unref gedit_mdi.");
-
-	g_object_unref (G_OBJECT (gedit_mdi));
-
-	gedit_debug_message (DEBUG_FILE, "Unref gedit_mdi: DONE");
-
-	gedit_debug_message (DEBUG_FILE, "Unref gedit_app_server.");
-
-	bonobo_object_unref (gedit_app_server);
-
-	gedit_debug_message (DEBUG_FILE, "Unref gedit_app_server: DONE");
-#endif
-
 	gtk_main_quit ();
 }
 
@@ -421,7 +401,7 @@ gedit_session_init (void)
 	gedit_debug (DEBUG_SESSION);
 	
 	if (master_client)
-	  return;
+		return;
 
 	master_client = egg_sm_client_get ();
 	g_signal_connect (master_client,
@@ -465,7 +445,8 @@ gedit_session_is_restored (void)
 }
 
 static void
-parse_window (GKeyFile *state_file, const char *group_name)
+parse_window (GKeyFile    *state_file,
+	      const gchar *group_name)
 {
 	GeditWindow *window;
 	gchar *role, *active_document, **documents;
@@ -473,7 +454,7 @@ parse_window (GKeyFile *state_file, const char *group_name)
 	gboolean visible;
 	GeditPanel *panel;
 	GError *error = NULL;
-  
+
 	role = g_key_file_get_string (state_file, group_name, "role", NULL);
 
 	gedit_debug_message (DEBUG_SESSION, "Window role: %s", role);
@@ -491,60 +472,51 @@ parse_window (GKeyFile *state_file, const char *group_name)
 					"width", &error);
 	if (error)
 	{
-	        g_clear_error (&error);
+		g_clear_error (&error);
 		width = -1;
 	}
 	height = g_key_file_get_integer (state_file, group_name,
 					 "height", &error);
 	if (error)
 	{
-	        g_clear_error (&error);
+		g_clear_error (&error);
 		height = -1;
 	}
 	gtk_window_set_default_size (GTK_WINDOW (window), width, height);
-  
- 
+
 	visible = g_key_file_get_boolean (state_file, group_name,
 					  "side-panel-visible", &error);
 	if (error)
 	{
-	        g_clear_error (&error);
+		g_clear_error (&error);
 		visible = FALSE;
 	}
-  
+
 	panel = gedit_window_get_side_panel (window);
-  
+	gtk_widget_set_visible (GTK_WIDGET (panel), visible);
+
 	if (visible)
 	{
-	        gedit_debug_message (DEBUG_SESSION, "Side panel visible");
-		gtk_widget_show (GTK_WIDGET (panel));
+		gedit_debug_message (DEBUG_SESSION, "Side panel visible");
 	}
 	else
 	{
-	      gedit_debug_message (DEBUG_SESSION, "Side panel _NOT_ visible");
-	      gtk_widget_hide (GTK_WIDGET (panel));
+		gedit_debug_message (DEBUG_SESSION, "Side panel _NOT_ visible");
 	}
-  
+
 	visible = g_key_file_get_boolean (state_file, group_name,
 					  "bottom-panel-visible", &error);
 	if (error)
 	{
-	        g_clear_error (&error);
+		g_clear_error (&error);
 		visible = FALSE;
 	}
-  
-	panel = gedit_window_get_bottom_panel (window);
-	if (visible)
-	{
-	        gedit_debug_message (DEBUG_SESSION, "Bottom panel visible");
-		gtk_widget_show (GTK_WIDGET (panel));
-	}
-	else
-	{
-	        gedit_debug_message (DEBUG_SESSION, "Bottom panel _NOT_ visible");
-		gtk_widget_hide (GTK_WIDGET (panel));
-	}
 
+	panel = gedit_window_get_bottom_panel (window);
+	gtk_widget_set_visible (GTK_WIDGET (panel), visible);
+	gedit_debug_message (DEBUG_SESSION, "Bottom panel %svisible",
+			     visible ? "" : "_NOT_ ");
+	
 	active_document = g_key_file_get_string (state_file, group_name,
 						 "active-document", NULL);
 	documents = g_key_file_get_string_list (state_file, group_name,
@@ -559,8 +531,10 @@ parse_window (GKeyFile *state_file, const char *group_name)
 			GFile *location;
 
 			if (active_document != NULL)
+			{
 				jump_to = strcmp (active_document,
 						  documents[i]) == 0;
+			}
 
 			gedit_debug_message (DEBUG_SESSION,
 					     "URI: %s (%s)",
@@ -582,7 +556,7 @@ parse_window (GKeyFile *state_file, const char *group_name)
 	}
 
 	g_free (active_document);
-	
+
 	gtk_widget_show (GTK_WIDGET (window));
 }
 
@@ -599,7 +573,7 @@ gedit_session_load (void)
 {
 	GKeyFile *state_file;
 	gchar **groups;
-	int i;
+	gint i;
 
 	gedit_debug (DEBUG_SESSION);
 
@@ -620,4 +594,5 @@ gedit_session_load (void)
 
 	return TRUE;
 }
+
 /* ex:ts=8:noet: */
