@@ -68,7 +68,7 @@ typedef struct _GeditWindowPrivate GeditWindowPrivate;
  */
 typedef struct _GeditWindow GeditWindow;
 
-struct _GeditWindow 
+struct _GeditWindow
 {
 	GtkWindow window;
 
@@ -81,15 +81,15 @@ struct _GeditWindow
  */
 typedef struct _GeditWindowClass GeditWindowClass;
 
-struct _GeditWindowClass 
+struct _GeditWindowClass
 {
 	GtkWindowClass parent_class;
-	
+
 	/* Signals */
 	void	 (* tab_added)      	(GeditWindow *window,
-				     	 GeditTab    *tab);
+					 GeditTab    *tab);
 	void	 (* tab_removed)    	(GeditWindow *window,
-				     	 GeditTab    *tab);
+					 GeditTab    *tab);
 	void	 (* tabs_reordered) 	(GeditWindow *window);
 	void	 (* active_tab_changed)	(GeditWindow *window,
 				     	 GeditTab    *tab);
@@ -104,22 +104,30 @@ GType 		 gedit_window_get_type 			(void) G_GNUC_CONST;
 
 GeditTab	*gedit_window_create_tab		(GeditWindow         *window,
 							 gboolean             jump_to);
-							 
-GeditTab	*gedit_window_create_tab_from_uri	(GeditWindow         *window,
-							 const gchar         *uri,
+
+GeditTab	*gedit_window_create_tab_from_location	(GeditWindow         *window,
+							 GFile               *location,
 							 const GeditEncoding *encoding,
 							 gint                 line_pos,
+							 gint                 column_pos,
 							 gboolean             create,
 							 gboolean             jump_to);
-							 
+
+GeditTab	*gedit_window_create_tab_from_stream	(GeditWindow         *window,
+							 GInputStream        *stream,
+							 const GeditEncoding *encoding,
+							 gint                 line_pos,
+							 gint                 column_pos,
+							 gboolean             jump_to);
+
 void		 gedit_window_close_tab			(GeditWindow         *window,
 							 GeditTab            *tab);
-							 
+
 void		 gedit_window_close_all_tabs		(GeditWindow         *window);
 
 void		 gedit_window_close_tabs		(GeditWindow         *window,
 							 const GList         *tabs);
-							 
+
 GeditTab	*gedit_window_get_active_tab		(GeditWindow         *window);
 
 void		 gedit_window_set_active_tab		(GeditWindow         *window,
@@ -154,9 +162,6 @@ GeditWindowState gedit_window_get_state 		(GeditWindow         *window);
 GeditTab        *gedit_window_get_tab_from_location	(GeditWindow         *window,
 							 GFile               *location);
 
-GeditTab        *gedit_window_get_tab_from_uri		(GeditWindow         *window,
-							 const gchar         *uri);
-
 /* Message bus */
 GeditMessageBus	*gedit_window_get_message_bus		(GeditWindow         *window);
 
@@ -183,13 +188,17 @@ void		 _gedit_window_unfullscreen		(GeditWindow         *window);
 
 gboolean	 _gedit_window_is_fullscreen		(GeditWindow         *window);
 
+GList		*_gedit_window_get_all_tabs		(GeditWindow         *window);
+
 /* these are in gedit-window because of screen safety */
 void		 _gedit_recent_add			(GeditWindow	     *window,
-							 const gchar         *uri,
+							 GFile               *location,
 							 const gchar         *mime);
 void		 _gedit_recent_remove			(GeditWindow         *window,
-							 const gchar         *uri);
+							 GFile               *location);
 
 G_END_DECLS
 
 #endif  /* __GEDIT_WINDOW_H__  */
+
+/* ex:ts=8:noet: */
