@@ -41,11 +41,18 @@ typedef int Py_ssize_t;
 
 #define GEDIT_PLUGIN_LOADER_PYTHON_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_PLUGIN_LOADER_PYTHON, GeditPluginLoaderPythonPrivate))
 
+typedef enum {
+	GEDIT_PYTHON_STATUS_NOT_RUN,
+	GEDIT_PYTHON_STATUS_FAILED,
+	GEDIT_PYTHON_STATUS_SUCCESS
+} GeditPythonStatusType;
+
 struct _GeditPluginLoaderPythonPrivate
 {
 	GHashTable *loaded_plugins;
 	guint idle_gc;
-	gboolean init_failed;
+	GeditPythonStatusType status;
+	PyThreadState *py_thread_state;
 };
 
 typedef struct
@@ -208,24 +215,31 @@ gedit_plugin_loader_iface_load (GeditPluginLoader *loader,
 	PyObject *pymodule, *fromlist;
 	gchar *module_name;
 	GeditPlugin *result;
+	PyGILState_STATE state;
 	
-	if (pyloader->priv->init_failed)
+	if (pyloader->priv->status != GEDIT_PYTHON_STATUS_SUCCESS)
 	{
 		g_warning ("Cannot load python plugin Python '%s' since gedit was"
 		           "not able to initialize the Python interpreter.",
 		           gedit_plugin_info_get_name (info));
 		return NULL;
 	}
-	
+
+	state = pyg_gil_state_ensure ();
+
 	/* see if py definition for the plugin is already loaded */
 	result = new_plugin_from_info (pyloader, info);
 	
 	if (result != NULL)
+	{
+		pyg_gil_state_release (state);
 		return result;
+	}
 	
 	main_module = PyImport_AddModule ("gedit.plugins");
 	if (main_module == NULL)
 	{
+		pyg_gil_state_release (state);
 		g_warning ("Could not get gedit.plugins.");
 		return NULL;
 	}
@@ -260,6 +274,9 @@ gedit_plugin_loader_iface_load (GeditPluginLoader *loader,
 	{
 		g_free (module_name);
 		PyErr_Print ();
+
+		pyg_gil_state_release (state);
+
 		return NULL;
 	}
 
@@ -269,8 +286,14 @@ gedit_plugin_loader_iface_load (GeditPluginLoader *loader,
 	pytype = find_python_plugin_type (info, pymodule);
 	
 	if (pytype)
-		return add_python_info (pyloader, info, pymodule, path, pytype);
+	{
+		GeditPlugin *plugin = add_python_info (pyloader, info, pymodule, path, pytype);
+		pyg_gil_state_release (state);
 
+		return plugin;
+	}
+
+	pyg_gil_state_release (state);
 	return NULL;
 }
 
@@ -294,11 +317,21 @@ gedit_plugin_loader_iface_unload (GeditPluginLoader *loader,
 	pyinfo->instance = NULL;
 }
 
+static void
+run_gc_protected (void)
+{
+	PyGILState_STATE state = pyg_gil_state_ensure ();
+
+	while (PyGC_Collect ())
+		;
+
+	pyg_gil_state_release (state);
+}
+
 static gboolean
 run_gc (GeditPluginLoaderPython *loader)
 {
-	while (PyGC_Collect ())
-		;
+	run_gc_protected ();
 
 	loader->priv->idle_gc = 0;
 	return FALSE;
@@ -307,20 +340,17 @@ run_gc (GeditPluginLoaderPython *loader)
 static void
 gedit_plugin_loader_iface_garbage_collect (GeditPluginLoader *loader)
 {
-	GeditPluginLoaderPython *pyloader;
+	GeditPluginLoaderPython *pyloader = GEDIT_PLUGIN_LOADER_PYTHON (loader);
 	
-	if (!Py_IsInitialized())
+	if (pyloader->priv->status != GEDIT_PYTHON_STATUS_SUCCESS)
 		return;
 
-	pyloader = GEDIT_PLUGIN_LOADER_PYTHON (loader);
-
 	/*
 	 * We both run the GC right now and we schedule
 	 * a further collection in the main loop.
 	 */
 
-	while (PyGC_Collect ())
-		;
+	run_gc_protected ();
 
 	if (pyloader->priv->idle_gc == 0)
 		pyloader->priv->idle_gc = g_idle_add ((GSourceFunc)run_gc, pyloader);
@@ -341,8 +371,18 @@ gedit_plugin_loader_iface_init (gpointer g_iface,
 static void
 gedit_python_shutdown (GeditPluginLoaderPython *loader)
 {
-	if (!Py_IsInitialized ())
+	GeditPluginLoaderPython *pyloader = GEDIT_PLUGIN_LOADER_PYTHON (loader);
+
+	if (pyloader->priv->status != GEDIT_PYTHON_STATUS_SUCCESS)
+	{
+		if (loader->priv->py_thread_state)
+		{
+			PyEval_RestoreThread (loader->priv->py_thread_state);
+			loader->priv->py_thread_state = NULL;
+		}
+
 		return;
+	}
 
 	if (loader->priv->idle_gc != 0)
 	{
@@ -350,9 +390,9 @@ gedit_python_shutdown (GeditPluginLoaderPython *loader)
 		loader->priv->idle_gc = 0;
 	}
 
-	while (PyGC_Collect ())
-		;	
+	run_gc_protected ();
 
+	pyg_gil_state_ensure ();
 	Py_Finalize ();
 }
 
@@ -406,6 +446,9 @@ gedit_init_pygtk (void)
 
 	init_pygtk ();
 
+	/* Initialize support for threads */
+	pyg_enable_threads ();
+
 	/* there isn't init_pygtk_check(), do the version
 	 * check ourselves */
 	gtk = PyImport_ImportModule("gtk");
@@ -486,34 +529,36 @@ gedit_python_init (GeditPluginLoaderPython *loader)
 	PyObject *mdict, *tuple;
 	PyObject *gedit, *geditutils, *geditcommands, *geditplugins;
 	PyObject *gettext, *install, *gettext_args;
-	struct sigaction old_sigint;
-	gint res;
 	char *argv[] = { "gedit", NULL };
+#ifdef HAVE_SIGACTION
+	gint res;
+	struct sigaction old_sigint;
+#endif
 
-	if (loader->priv->init_failed)
+	if (loader->priv->status == GEDIT_PYTHON_STATUS_FAILED)
 	{
 		/* We already failed to initialized Python, don't need to
 		 * retry again */
 		return FALSE;
 	}
 	
-	if (Py_IsInitialized ())
+	if (loader->priv->status == GEDIT_PYTHON_STATUS_SUCCESS)
 	{
 		/* Python has already been successfully initialized */
 		return TRUE;
 	}
 
 	/* We are trying to initialize Python for the first time,
-	   set init_failed to FALSE only if the entire initialization process
+	   set status to GEDIT_PYTHON_STATUS_SUCCESS only if the entire initialization process
 	   ends with success */
-	loader->priv->init_failed = TRUE;
+	loader->priv->status = GEDIT_PYTHON_STATUS_FAILED;
 
 	/* Hack to make python not overwrite SIGINT: this is needed to avoid
-	 * the crash reported on bug #326191 */
-
-	/* CHECK: can't we use Py_InitializeEx instead of Py_Initialize in order
-          to avoid to manage signal handlers ? - Paolo (Dec. 31, 2006) */
+	 * the crash reported on bug #326191. It's actually the signal
+	 * module that overrides SIGINT when it's set to the default,
+	 * so using Py_InitializeEx (0) also does not work */
 
+#ifdef HAVE_SIGACTION
 	/* Save old handler */
 	res = sigaction (SIGINT, NULL, &old_sigint);  
 	if (res != 0)
@@ -524,10 +569,13 @@ gedit_python_init (GeditPluginLoaderPython *loader)
 
 		return FALSE;
 	}
+#endif
 
 	/* Python initialization */
-	Py_Initialize ();
+	if (!Py_IsInitialized ())
+		Py_Initialize ();
 
+#ifdef HAVE_SIGACTION
 	/* Restore old handler */
 	res = sigaction (SIGINT, &old_sigint, NULL);
 	if (res != 0)
@@ -538,6 +586,7 @@ gedit_python_init (GeditPluginLoaderPython *loader)
 
 		goto python_init_error;
 	}
+#endif
 
 	PySys_SetArgv (1, argv);
 
@@ -634,8 +683,10 @@ gedit_python_init (GeditPluginLoaderPython *loader)
 	Py_DECREF (gettext_args);
 	
 	/* Python has been successfully initialized */
-	loader->priv->init_failed = FALSE;
-	
+	loader->priv->status = GEDIT_PYTHON_STATUS_SUCCESS;
+
+	loader->priv->py_thread_state = PyEval_SaveThread();
+
 	return TRUE;
 	
 python_init_error:
@@ -710,3 +761,4 @@ gedit_plugin_loader_python_new ()
 	return GEDIT_PLUGIN_LOADER_PYTHON (loader);
 }
 
+/* ex:ts=8:noet: */
