@@ -618,7 +618,7 @@ class Manager:
         
         def on_dialog_snippets_response(self, dlg, resp):                                
                 if resp == gtk.RESPONSE_HELP:
-                        gedit.help_display(self.dlg, 'gedit', 'gedit-snippets-plugin')
+                        gedit.app_get_default().show_help(self.dlg, 'gedit', 'gedit-snippets-plugin')
                         return
 
                 self.dlg.destroy()
@@ -765,11 +765,12 @@ class Manager:
                 success = True
                 
                 for filename in filenames:
-                        if not gedit.utils.uri_has_file_scheme(filename):
+                        gfile = gio.File(filename)
+
+                        if not gedit.utils.location_has_file_scheme(gfile):
                                 continue
 
                         # Remove file://
-                        gfile = gio.File(filename)
                         filename = gfile.get_path()
 
                         importer = Importer(filename)
