@@ -32,9 +32,13 @@
 #endif
 
 #include <string.h>
+
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+
 #include <gedit/gedit-utils.h>
+#include <gedit/gseal-gtk-compat.h>
+
 #include "gedit-spell-checker-dialog.h"
 #include "gedit-spell-marshal.h"
 
@@ -291,7 +295,7 @@ create_dialog (GeditSpellCheckerDialog *dlg,
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
 
 	/* Set default button */
-	GTK_WIDGET_SET_FLAGS (dlg->change_button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (dlg->change_button, TRUE);
 	gtk_widget_grab_default (dlg->change_button);
 
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->word_entry), TRUE);
@@ -450,6 +454,8 @@ update_suggestions_list_model (GeditSpellCheckerDialog *dlg, GSList *suggestions
 	{
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
+		                    /* Translators: Displayed in the "Check Spelling" dialog if there are no suggestions
+		                     * for the current misspelled word */
 				    COLUMN_SUGGESTIONS, _("(no suggested words)"),
 				    -1);
 
@@ -556,6 +562,7 @@ check_word_button_clicked_handler (GtkButton *button, GeditSpellCheckerDialog *d
 
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter,
+		                    /* Translators: Displayed in the "Check Spelling" dialog if the current word isn't misspelled */
 				    COLUMN_SUGGESTIONS, _("(correct spelling)"),
 				    -1);
 
@@ -717,3 +724,4 @@ gedit_spell_checker_dialog_set_completed (GeditSpellCheckerDialog *dlg)
 	gtk_widget_set_sensitive (dlg->suggestions_list, FALSE);
 }
 
+/* ex:ts=8:noet: */
