@@ -33,7 +33,6 @@
 #include <gmodule.h>
 
 #include <gedit/gedit-debug.h>
-#include <gedit/gedit-prefs-manager.h>
 #include <gedit/gedit-statusbar.h>
 
 #include "gedit-spell-checker.h"
@@ -102,7 +101,7 @@ static const GtkToggleActionEntry toggle_action_entries[] =
 {
 	{ "AutoSpell",
 	  NULL,
-	  N_("_Autocheck Spelling"),
+	  N_("_Highlight Misspelled Words"),
 	  NULL,
 	  N_("Automatically spell-check the current document"),
 	  G_CALLBACK (auto_spell_cb),
