@@ -218,7 +218,7 @@ test_saver (const gchar              *filename_or_uri,
 	ensure_mounted (file);
 
 	gedit_document_save_as (document, file, gedit_encoding_get_utf8 (),
-			        newline_type, save_flags);
+			        newline_type, 0, save_flags);
 
 	while (!test_completed)
 	{
@@ -688,8 +688,6 @@ int main (int   argc,
 	g_type_init ();
 	g_test_init (&argc, &argv, NULL);
 
-	gedit_prefs_manager_app_init ();
-
 	g_printf ("\n***\n");
 	have_unowned = check_unowned_directory ();
 	have_unowned_group = check_unowned_group ();
